@@ -39,7 +39,7 @@
 // constants
 
 
-static const char * const Version = "1.4.70b";
+static const char * const Version = "2.0.4";
 static const char * const HelpMessage = "\
 SYNTAX\n\
 * polyglot [configfile] [-noini] [-ec engine] [-ed enginedirectory] [-en enginename] [-log true/false] [-lf logfile] [-pg <name>=<value>]* [-uci <name>=<value>]*\n\
@@ -443,6 +443,10 @@ int main(int argc, char * argv[]) {
 
         // start engine
     
+    if((entry=ini_find(ini,"polyglot","Affinity"))){ // must be known during start
+        polyglot_set_option(entry->name,entry->value);
+    }
+
     engine_open(Engine);
 
     if(!engine_active(Engine)){
