@@ -130,7 +130,7 @@ void uci_open(uci_t * uci, engine_t * engine) {
    uci->engine = engine;
 
    uci->name = NULL;
-   my_string_set(&uci->name,"<empty>");
+   my_string_set(&uci->name,"unknown");
    uci->author = NULL;
    my_string_set(&uci->author,"<empty>");
    option_init(uci->option);
@@ -715,6 +715,8 @@ static int parse_info(uci_t * uci, const char string[]) {
          ln = my_atoll(argument);
          ASSERT(ln>=0);
 
+         if (ln >= 0) uci->tbhit_nb = ln;
+
       } else if (my_string_equal(option,"time")) {
 
          ASSERT(!my_string_empty(argument));
@@ -897,6 +899,8 @@ static void parse_score(uci_t * uci, const char string[]) {
    parse_add_keyword(parse,"mate");
    parse_add_keyword(parse,"upperbound");
 
+   uci->bound_type = '\0'; // [HGM] bound: assume exact score
+
    // loop
 
    while (parse_get_word(parse,option,StringSize)) {
@@ -919,6 +923,8 @@ static void parse_score(uci_t * uci, const char string[]) {
 
          ASSERT(my_string_empty(argument));
 
+         uci->bound_type = '!';
+
       } else if (my_string_equal(option,"mate")) {
 
          ASSERT(!my_string_empty(argument));
@@ -932,6 +938,8 @@ static void parse_score(uci_t * uci, const char string[]) {
 
          ASSERT(my_string_empty(argument));
 
+         uci->bound_type = '?';
+
       } else {
 
          my_log("POLYGLOT unknown option \"%s\" for command \"%s\"\n",option,command);
@@ -945,13 +953,17 @@ static void parse_score(uci_t * uci, const char string[]) {
 
 static int mate_score(int dist) {
 
+   int ms = option_get_int(Option,"MateScore");
+
    ASSERT(dist!=0);
 
    if (FALSE) {
+   } else if (ms == 0) {
+       return (dist > 0 ? 100000 + dist : -100000 + dist);
    } else if (dist > 0) {
-       return +option_get_int(Option,"MateScore") - (+dist) * 2 + 1;
+       return +ms - (+dist) * 2 + 1;
    } else if (dist < 0) {
-       return -option_get_int(Option,"MateScore") + (-dist) * 2;
+       return -ms + (-dist) * 2;
    }
 
    return 0;
